@@ -36,4 +36,8 @@ class HierarchicalAdmin(admin.ModelAdmin):
 		'slug': ('name',)
 	}
 	
-	form = HierarchicalAdminForm
\ No newline at end of file
+	form = HierarchicalAdminForm
+
+class SortableHierarchicalAdmin(HierarchicalAdmin):
+	list_display = HierarchicalAdmin.list_display + ('order',)
+	search_fields = ('name',)
\ No newline at end of file
